Signed-off-by: Rick Walsh <[email protected]>
---
 tests/testplan.cpp | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tests/testplan.cpp b/tests/testplan.cpp
index 737a085..3764882 100644
--- a/tests/testplan.cpp
+++ b/tests/testplan.cpp
@@ -413,8 +413,8 @@ void TestPlan::testVpmbMetric100m60min()
        QCOMPARE(ev->gas.index, 2);
        QCOMPARE(ev->value, 100);
        QCOMPARE(get_depth_at_time(&displayed_dive.dc, ev->time.seconds), 6000);
-       // check expected run time of 316 minutes
-       QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 316u * 60u 
+ 20u));
+       // check expected run time of 311 minutes
+       QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 311u * 60u 
+ 20u));
 }
 
 void TestPlan::testVpmbMetricMultiLevelAir()
-- 
2.4.3

_______________________________________________
subsurface mailing list
[email protected]
http://lists.subsurface-divelog.org/cgi-bin/mailman/listinfo/subsurface

Reply via email to